function C_divergence = divergence_matrix(x, y, z, i, j, k, Nc)
	%% construct divergence operator
	% for an array umat which is of size Nc x Nx x Ny x Nz, Nc >= 3
	%
	% we construct a constraint umat(:)' * C = 0;
	% 
	% we have a grid x, y, z and we want a matrix representing the application o
	% of the divergence operator on a grid x(i), y(j), z(k)
	%
	
	%% sizes of stuff
	dx							= x(2) - x(1);
	dy							= y(2) - y(1);
	dz							= z(2) - z(1);
	Nx							= length(x);
	Ny							= length(y);
	Nz							= length(z);
	Ni							= length(i);
	Nj							= length(j);
	Nk							= length(k);
	N_tot						= Nx * Ny * Nz;
	N_div						= Ni * Nj * Nk;
	if nargin < 7			% optional: there may be more than just velocity data in the matrix
		Nc						= 3;
	end
	S							= [Nc Nx Ny Nz];

	%% generate grid of indices
	[imat, jmat, kmat]	= ndgrid(i, j, k);
	imat						= imat(:);
	jmat						= jmat(:);
	kmat						= kmat(:);

	%% generate linear indices
	% linear index of points (i+-1,j+-1,k+-1) in velocity array
	% which is 3 x Nx x Ny x Nz
	u011						= sub2ind(S, 1*ones(N_div,1), imat-1, jmat  , kmat  );
	u211						= sub2ind(S, 1*ones(N_div,1), imat+1, jmat  , kmat  );
	v101						= sub2ind(S, 2*ones(N_div,1), imat  , jmat-1, kmat  );
	v121						= sub2ind(S, 2*ones(N_div,1), imat  , jmat+1, kmat  );
	w110						= sub2ind(S, 3*ones(N_div,1), imat  , jmat  , kmat-1);
	w112						= sub2ind(S, 3*ones(N_div,1), imat  , jmat  , kmat+1);

	%% populate matrix
	% divergence at each point requires up to 6 velocity coefficients
	% create coefficients to populate sparse matrix
	% div(u)*(2dx) = u(i+1,j,k) - u(i-1,j,k)
	%              + v(i,j+1,k) - v(i,j-1,k)
	%              + w(i,j,k+1) - w(i,j,k-1)
	ivec						= zeros(6, N_div);
	jvec						= zeros(6, N_div);
	svec						= zeros(6, N_div);
	for it = 1 : N_div
		ivec(:, it)			= [u211(it) u011(it) v121(it) v101(it) w112(it) w110(it)]';
		jvec(:, it)			= it;
		svec(:, it)			= [+1/dx    -1/dx    +1/dy    -1/dy    +1/dz    -1/dz   ]'/2;
	end
	% populate sparse matrix
	C_divergence			= sparse(ivec(:), jvec(:), svec(:), Nc*N_tot, N_div);
end