% the trilinear interpolation of f(x,y,z) over the domain
% [0,1], [0,1], [0,1] is given by
% F(x,y,z) = f000*(1 - x - y - z + x*y + x*z + y*z - x*y*z)
%			  + f001*(            z       - x*z - y*z + x*y*z)
%			  + f010*(        y     - x*y       - y*z + x*y*z)
%			  + f011*(                            y*z - x*y*z)
%			  + f100*(    x         - x*y - x*z       + x*y*z)
%			  + f101*(                      x*z       - x*y*z)
%			  + f110*(                x*y             - x*y*z)
%			  + f111*(                                + x*y*z)
%
% where
% x = (x' - x_1)/(x_2 - x_1)
% y = (y' - y_1)/(y_2 - y_1)
% z = (z' - z_1)/(z_2 - z_1)

syms u000 u001 u010 u011 u100 u101 u110 u111
syms v000 v001 v010 v011 v100 v101 v110 v111
syms w000 w001 w010 w011 w100 w101 w110 w111

syms x y z
syms dx dy dz
syms xp yp zp

xp			= x / dx;
yp			= y / dy;
zp			= z / dz;

U			= u000*(1 - xp - yp - zp + xp*yp + xp*zp + yp*zp - xp*yp*zp) ...
		   + u001*(              zp         - xp*zp - yp*zp + xp*yp*zp) ...
		   + u010*(         yp      - xp*yp         - yp*zp + xp*yp*zp) ...
		   + u011*(                                   yp*zp - xp*yp*zp) ...
		   + u100*(    xp           - xp*yp - xp*zp         + xp*yp*zp) ...
		   + u101*(                           xp*zp         - xp*yp*zp) ...
		   + u110*(                   xp*yp                 - xp*yp*zp) ...
		   + u111*(                                         + xp*yp*zp);
V			= v000*(1 - xp - yp - zp + xp*yp + xp*zp + yp*zp - xp*yp*zp) ...
		   + v001*(              zp         - xp*zp - yp*zp + xp*yp*zp) ...
		   + v010*(         yp      - xp*yp         - yp*zp + xp*yp*zp) ...
		   + v011*(                                   yp*zp - xp*yp*zp) ...
		   + v100*(    xp           - xp*yp - xp*zp         + xp*yp*zp) ...
		   + v101*(                           xp*zp         - xp*yp*zp) ...
		   + v110*(                   xp*yp                 - xp*yp*zp) ...
		   + v111*(                                         + xp*yp*zp);
W			= w000*(1 - xp - yp - zp + xp*yp + xp*zp + yp*zp - xp*yp*zp) ...
		   + w001*(              zp         - xp*zp - yp*zp + xp*yp*zp) ...
		   + w010*(         yp      - xp*yp         - yp*zp + xp*yp*zp) ...
		   + w011*(                                   yp*zp - xp*yp*zp) ...
		   + w100*(    xp           - xp*yp - xp*zp         + xp*yp*zp) ...
		   + w101*(                           xp*zp         - xp*yp*zp) ...
		   + w110*(                   xp*yp                 - xp*yp*zp) ...
		   + w111*(                                         + xp*yp*zp);
		
% with this definition, we get
% F(0 ,0 ,0 ) = f000
% F(0 ,0 ,dz) = f001
% F(0 ,dy,0 ) = f010
% etc.
		
% integrate flux over faces
flux_x	= int(int(U, z, 0, dz), y, 0, dy);
flux_y	= int(int(V, x, 0, dx), z, 0, dz);
flux_z	= int(int(W, x, 0, dx), y, 0, dy);

% compute divergence from stokes' theorem
F_div		=(subs(flux_x, x, dx) - subs(flux_x, x, 0) ...
			+ subs(flux_y, y, dy) - subs(flux_y, y, 0) ...
			+ subs(flux_z, z, dz) - subs(flux_z, z, 0)) / (dx*dy*dz);
F_div		= expand(F_div);
%F_div		= collect(F_div, [f000 f001 f010 f011 f100 f101 f110 f111]);
F_div		= collect(F_div, [u000 u001 u010 u011 u100 u101 u110 u111  v000 v001 v010 v011 v100 v101 v110 v111 w000 w001 w010 w011 w100 w101 w110 w111]);
pretty(F_div*-4);