function ij = radial_distortion(ijstar, ic, kr)
	% apply radial distortion, to map from
	% (undistorted) pinhole image coordinates i* and j*
	% (distorted) real world image coordinates i and j
	%
	% r^2 = (i* - i0)^2 + (j* - j0)^2
	% i   = i0 + (i* - i0)*(1 + k1*r^2 + k2*r^4)
	% j   = j0 + (j* - j0)*(1 + k1*r^2 + k2*r^4)
	
	i0		= ic(1);
	j0		= ic(2);
	k1		= kr(1);
	k2		= kr(2);
	istar = ijstar(1,:);
	jstar = ijstar(2,:);
	
	rsq	= (istar - i0).^2 + (jstar - j0).^2;
	i		= i0 + (istar - i0).*(1 + k1*rsq + k2*rsq.^2);
	j		= j0 + (jstar - j0).*(1 + k1*rsq + k2*rsq.^2);
	
	ij		= [i; j];	
end