#include "mex.h"
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#define MAX_DIMENSION		16384
#define MIN_DIMENSION		2

void mexFunction(	int nlhs,	mxArray *plhs[],
						int nrhs,	const mxArray *prhs[])
{
	/******
	 * im = imread_raw12(fname, Nx, Ny)
	 * read an image from .raw12 file specified by fname
	 * as a raw 12 bit/pixel monochrome image file
	 * with size given by Nx x Ny
	 */
	char *pFileName;
	unsigned short *pBuffer16;
	unsigned char *pBuffer8;
	FILE *fp;
	const mxArray *mxFileName;
	mxArray *mxImageMat;
	const mxArray *mxNx, *mxNy;
	size_t nFileName;
	unsigned nWords, nBytes, n;
	size_t nRead;
	unsigned short w1, w2;
	int N[2];

	/* check number of arguments */
	if(nrhs != 3)
	{
		mexErrMsgTxt("Wrong number of input arguments");
		return;
	}
	mxFileName	= prhs[0];
	mxNx			= prhs[1];
	mxNy			= prhs[2];
	if(nlhs != 1)
	{
		mexErrMsgTxt("Wrong numer of output arguments");
		return;
	}

	/* parse filename argument */
	if(!mxIsClass(mxFileName, "char"))
	{
		mexErrMsgTxt("imread_raw12(fname, Nx, Ny): fname should be a filename");
		return;
	}
	nFileName	= mxGetNumberOfElements(mxFileName);
	pFileName	= (char*)malloc((nFileName+1) * sizeof(char));
	if(mxGetString(mxFileName, pFileName, nFileName+1))
	{
		mexErrMsgTxt("imread_raw12(fname, Nx, Ny): fname should be a filename");
		return;
	}

	/* parse image size argument */
	if(!mxIsNumeric(mxNx))
	{
		mexErrMsgTxt("imread_raw12(fname, Nx, Ny): Nx should be a numeric, positive integer describing the size of the image");
		return;
	}
	if(!mxIsNumeric(mxNy))
	{
		mexErrMsgTxt("imread_raw12(fname, Nx, Ny): Ny should be a numeric, positive integer describing the size of the image");
		return;
	}
	N[0]			= (int)mxGetScalar(mxNx);
	N[1]			= (int)mxGetScalar(mxNy);
	if(N[0] < MIN_DIMENSION || N[0] > MAX_DIMENSION)
	{
		mexErrMsgTxt("imread_raw12(fname, Nx, Ny): Nx should be a numeric, positive integer describing the size of the image");
		return;
	}
	if(N[1] < MIN_DIMENSION || N[1] > MAX_DIMENSION)
	{
		mexErrMsgTxt("imread_raw12(fname, Nx, Ny): Nx should be a numeric, positive integer describing the size of the image");
		return;
	}


	/* allocate data for result */
	mxImageMat	= mxCreateNumericMatrix(N[0], N[1], mxUINT16_CLASS, mxREAL);
	pBuffer16	= (const unsigned short*)mxGetData(mxImageMat);
	nWords		= N[0] * N[1];
	nBytes		= (nWords * 3) / 2;
	plhs[0]		= mxImageMat;

	/* attempt to open file */
	fp	= fopen(pFileName, "rb");
	if(!fp)
	{
		mexErrMsgTxt("imread_raw12: unable to open file");
		return;
	}
	
	/* read from file */
	pBuffer8	= (unsigned char*) malloc(nBytes);
	nRead		= fread(pBuffer8, 1, nBytes, fp);
	fclose(fp);

	if(nRead != nBytes)
	{
		mexErrMsgTxt("imread_raw12: read wrong number of bytes. is the image size correct?");
		return;
	}
	for(n = 0; n < nWords; n+=2)
	{
		// word 1: 8 MSB are in byte 0
		//         4 LSB are the 4 MSB of byte 1
		// word 2: 4 MSB are the 4 LSB of byte 1
		//         8 LSB are in byte 2
		pBuffer16[n+0]	= (pBuffer8[(n*3/2) + 0] << 4) | ((pBuffer8[(n*3/2) + 1]>>4) & 0x00F);
		pBuffer16[n+1]	= (pBuffer8[(n*3/2) + 2]     ) | ((pBuffer8[(n*3/2) + 1]<<8) & 0xF00);
	}

	/* free memory */
	free(pFileName);
	free(pBuffer8);

	return;
}
