clear

graph_path = "/Users/natalie/Documents/year 3/IP/code/graphs";


%% variables
S = [1.0000    0.3201    0.2223; 
     0.1568    1.0000    0.3792;
     0.1095    0.4000    1.0000];

S = min(1, S*0.5625 + eye(3));

spill = true;
run_id = "standard_0.5625spill";

files = ["z001_t001.cam1.tif"  "z001_t001.cam2.tif"  "z001_t001.cam3.tif"  "z001_t001.cam4.tif"];

%% making the images

output_prefix = strjoin([graph_path "/" run_id], "");
mkdir(output_prefix);

if spill
    bayer_r = [S(1, 1), S(1, 2); S(1,2), S(1, 3)];
    bayer_g = [S(2, 1) S(2, 2); S(2, 2), S(2, 3)];
    bayer_b = [S(3, 1), S(3, 2); S(3, 2), S(3, 3)];
    tcf_calib(run_id, bayer_r, bayer_g, bayer_b)
else
    tcf_calib(run_id)
end

fprintf("tcf_calib done\n");
rgb_sig_init(run_id)
fprintf("rgb_sig_init done\n");
rgb_sig(run_id)
fprintf("rgb_sig done\n");
if spill
    janitor(run_id, S, files)
    fprintf("janitor done\n");
end

if spill
    proc_rgblpt(run_id, spill)
end

proc_rgblpt(run_id, false)

%% postprocessing
if spill
    figure()
    cleanmean = bulk_velocity(run_id, spill);
    saveas(gca, strjoin([output_prefix, "bulk_vel_nospill.png"], "/"))

    figure()
    hold on
    bl_plot(run_id, spill)
    plot([-150, 150], [cleanmean, cleanmean])
    hold off
    legend("actual data", "bulk velocity")
    title("Cleaned boundary layer profile for range $10<x<50$", "Interpreter", "latex")
    saveas(gca, strjoin([output_prefix, "boundary_layer_nospill.png"], "/"))
    
    

end

figure()
spillmean = bulk_velocity(run_id, false);
saveas(gca, strjoin([output_prefix, "bulk_vel_spill.png"], "/"))

figure()
hold on
bl_plot(run_id, false)
plot([-150, 150], [spillmean, spillmean])
hold off
legend("actual data", "bulk velocity")
title("Unprocessed boundary layer profile for range $10<x<50$", "Interpreter", "latex")
saveas(gca, strjoin([output_prefix, "boundary_layer_spill.png"], "/"))



fileID = fopen(strjoin([output_prefix, "report.txt"], "/"),'w');
fprintf(fileID, "datetime: %s\n", datestr(datetime));
fprintf(fileID, "does the thing below matter: %d\n", spill);
fprintf(fileID,"%d %d %d\n" ,S(1, 1), S(1, 2), S(1, 3));
fprintf(fileID,"%d %d %d\n" ,S(2, 1), S(2, 2), S(2, 3));
fprintf(fileID,"%d %d %d\n" ,S(3, 1), S(3, 2), S(3, 3));
fprintf(fileID, "\n");
fprintf(fileID, "mean velocity (unclean): %d \n", spillmean);
if spill
    fprintf(fileID, "mean velocity (clean): %d \n", cleanmean);
end
fclose(fileID);
