function series = get_track_property(obj, subset, tidx, property, asmatrix)
	% extract property of tracks
	% Input:
	%	subset	 subset of tracks to gather property (boolean/index)
	%	tidx     time index at which to gather property
	%	property name of property
    %   asmatrix gather into matrix with cell2mat?
	%
	% Output:
	%   series   1 x n_subset
	%	cell array containing property extracted at given instant for subset

    if nargin < 5
        asmatrix = false;
    end
    
	[~,n_tracks] = obj.count();
	if n_tracks == 0
		series = {};
	else
		if any(strcmp(property, {'ext','oob','t'}))
			series   = arrayfun(@(t) t.(property)(:, tidx), obj.tracks(1, subset), 'UniformOutput', true);
			return;
		else
			series   = arrayfun(@(t) t.(property)(:, :, tidx, :), obj.tracks(1, subset), 'UniformOutput', false);
		end
	end
	
    if asmatrix 
        n_subset= numel(series);
        series  = cell2mat(reshape(series, [1 1 n_subset]));
    end
end
