%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% initialise tracers for tracking through JHU turbulence database
addpath([pwd '/../../../turbmat']);
addpath([pwd '/../../core/mmx']);

%% input parameters
%St_range	= logspace(-3,0,7);
Fr			= 0;
St			= 0;%St_range(1);		% stokes number
beta		= 0;					% density
w_hat		= 0;

dset_dir	= 'L:/shadow/AR1.00/';
init_pat	= '%s/ic.mat';		% pattern of initial conditions file
dset_pat	= '%s/%d.mat';		% pattern of dataset files
n_tracers	= 100e3;			% number of tracers 
dt			= 0.002;			% timestep for logging
t0			= 0;				% start time
t1			= 0.2;			% end time

% kolmogorov lengthscales
tau_eta		= 0.0424;
nu			= 0.000185;
a_eta		= sqrt(nu/tau_eta^3);
u_eta		= sqrt(nu / tau_eta);

tau_p		= St * tau_eta;		% 
lambda		= 1;				% aspect ratio
g			= [0;0;a_eta/Fr];	% gravitational acceleration
w_min		= [0;0;w_hat*u_eta];% sinking speed
w_max		= [0;0;w_hat*u_eta];%
w0			= w_min;			% initial slip velocity

% JHU access
auth_token	= 'uk.ac.cam.dm529-ca4ff15b';
dset_token  = 'isotropic1024coarse';% dataset
s_interp	= 'Lag4';				% 4th order Lagrangian interpolation in space
g_interp	= 'Fd4Lag4';			% interpolation for GetVelocityGradient
t_interp	= 'None';				% no interpolation in time needed
nu			= 0.000185;				% kinematic viscosity

%% create initial distribution of tracers
% create random initial condition
rng(1);		% not-so-random random initial condition
xt_0		= rand(3,n_tracers)*2*pi;
R0			= randrotmat(n_tracers);

%% create time axis
t			= t0 : dt : t1;

%% create initialisation files
mkdir(dset_dir);
fname		= sprintf(init_pat, dset_dir);
fs			= struct();
fs.t		= t;
fs.x0		= xt_0;
fs.R0		= R0;
fs.s_interp	= s_interp;
fs.g_interp	= g_interp;
fs.t_interp = t_interp;
fs.auth_token=auth_token;
fs.dset_token=dset_token;
fs.tau_p	= tau_p;
fs.lambda	= lambda;
fs.beta		= beta;
fs.nu		= nu;
fs.tau_eta	= tau_eta;
fs.g		= g;
fs.w_min	= w_min;
fs.w_max	= w_max;
fprintf('saving initial conditions to %s\n', fname);
save(fname, '-struct', 'fs');

%% sample data at initial conditions
fprintf('querying database at t=%0.3f ...\n', t0);
dset_file	= sprintf(dset_pat, dset_dir, 1);

fprintf('   velocity...\n');
u0			= getVelocity(auth_token, dset_token, t0, s_interp, t_interp, n_tracers, xt_0);
fprintf('   gradient...\n');
A0			= getVelocityGradient(auth_token, dset_token, t0, g_interp, t_interp, n_tracers, xt_0);
A0			= permute(reshape(A0, [3 3 n_tracers]), [2 1 3]);

ds			= struct();
ds.x		= xt_0;
ds.u		= u0;
ds.A		= A0;
ds.t		= t0;

save(dset_file, '-struct', 'ds');